#delimit ;
set more off;
clear all;




* BOXING;
use olympics_boxing.dta;


	
* country clusters;
egen nat_id = group(country);
* tag dominant countries;
gen CSU = (nation == "CUB" | nation == "URS" | nation == "RUS" | nation == "USA");
* DVs;
gen KOTKO = (type == "KO" | type == "TKO" | type == "RSC");
gen points = (type == "points");
gen result2 = 0;
replace result2 = 1 if type == "TKO" | type == "KO" | type == "RSC";
replace result2 = 2 if type == "points";
tab result2; 
label def r3 2 "win-points" 1 "win-KO|TKO" ;
label values result2 r3;
* lag DVs;
g m1 = (medals1>0);
g m2 = (medals2>0);
g m3 = (medals3>0);



* MAIN TABLE;
* baseline: either type of win;
qui xi: logit winner boycott nation_count CSU ln_pop ln_GDP headgear escore host m1 m2 m3 i.weight  i.round, cl(nat_id);
est store boxing1;
* coefficient differences in mlogit
  m1KO > m1P at 1%
  m2KO < m2P at 5%
  m3KO < m3P at 10%
  hostKO < hostP at 10%;
qui xi: mlogit result2  boycott nation_count CSU ln_pop ln_GDP headgear escore host m1 m2 m3  i.weight  i.round, cl(nat_id);
est store boxing2;
test [win_KO_TKO]m1 - [win_points]m1 = 0;
test [win_KO_TKO]m2 - [win_points]m2 = 0;
test [win_KO_TKO]m3 - [win_points]m3 = 0;
test [win_KO_TKO]host - [win_points]host = 0;
estout _all, cells(b(star fmt(3)) t(par fmt(%9.2f)) ) stats(N r2_p ll chi2, star(chi2))
    starlevels(+ 0.10 * 0.05 ** 0.01)  drop( _* ) unstack style(fixed);
est clear;




* First Olympics - athlete level;
sort boxer nation recn;
by boxer nation: gen first = (_n == 1);
gen ytemp = year if first;
by boxer: egen ty = max(ytemp);
gen firsty = (year == ty);
qui xi: mlogit result2  boycott nation_count CSU ln_pop ln_GDP headgear escore host m1 m2 m3  i.weight  i.round  if firsty  , cl(nat_id);
est store boxing8a;
qui xi: mlogit result2  boycott nation_count CSU ln_pop ln_GDP headgear escore host m1 m2 m3  i.weight  i.round  if first  , cl(nat_id);
est store boxing8b;
estout _all, cells(b(star fmt(3)) t(par fmt(%9.2f)) ) stats(N r2_p ll chi2, star(chi2))
    starlevels(+ 0.10 * 0.05 ** 0.01)  drop( _* o.*) unstack style(fixed);
est clear;


* Pre and post electronic scoring;
* baseline: either type of win;
qui xi: logit winner boycott nation_count CSU ln_pop ln_GDP headgear escore host m1 m2 m3 i.weight  i.round if year <=1992, cl(nat_id);
est store boxing1;
qui xi: mlogit result2  boycott nation_count CSU ln_pop ln_GDP headgear escore host m1 m2 m3  i.weight  i.round if year <=1992, cl(nat_id);
est store boxing2;
estout _all, cells(b(star fmt(3)) t(par fmt(%9.2f)) ) stats(N r2_p ll chi2, star(chi2))
    starlevels(+ 0.10 * 0.05 ** 0.01)  drop( _* ) unstack style(fixed);
est clear;
qui xi: logit winner boycott nation_count CSU ln_pop ln_GDP headgear escore host m1 m2 m3 i.weight  i.round if year >1992, cl(nat_id);
est store boxing1;
qui xi: mlogit result2  boycott nation_count CSU ln_pop ln_GDP headgear escore host m1 m2 m3  i.weight  i.round if year >1992, cl(nat_id);
est store boxing2;
estout _all, cells(b(star fmt(3)) t(par fmt(%9.2f)) ) stats(N r2_p ll chi2, star(chi2))
    starlevels(+ 0.10 * 0.05 ** 0.01)  drop( _* ) unstack style(fixed);
est clear;


* randomly select from each pair;
gen rt = runiform();
sort recn rt;
by recn: gen keep = (_n == 1);
qui xi: mlogit result2  boycott nation_count CSU ln_pop ln_GDP headgear escore host m1 m2 m3  i.weight  i.round  if keep  , cl(nat_id);
est store boxing9a;
drop rt keep;
gen rt = runiform();
sort recn rt;
by recn: gen keep = (_n == 1);
qui xi: mlogit result2  boycott nation_count CSU ln_pop ln_GDP headgear escore host m1 m2 m3  i.weight  i.round  if keep  , cl(nat_id);
est store boxing9b;
drop rt keep;
gen rt = runiform();
sort recn rt;
by recn: gen keep = (_n == 1);
qui xi: mlogit result2  boycott nation_count CSU ln_pop ln_GDP headgear escore host m1 m2 m3  i.weight  i.round  if keep  , cl(nat_id);
est store boxing9c;

estout _all, cells(b(star fmt(3)) t(par fmt(%9.2f)) ) stats(N r2_p ll chi2, star(chi2))
    starlevels(+ 0.10 * 0.05 ** 0.01)  drop( _* o.*) unstack style(fixed);
est clear;




* DESCRIPTIVES;
corr winner KOTKO points m1 m2 m3 boycott nation_count  host ln_pop ln_GDP CSU headgear escore;
sum  winner KOTKO points m1 m2 m3 boycott nation_count  host ln_pop ln_GDP CSU headgear escore;



